@@ -1,5 +1,5 @@
 package Stepford::Runner::State;
-$Stepford::Runner::State::VERSION = '0.003001';
+$Stepford::Runner::State::VERSION = '0.003002';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -111,11 +111,11 @@ sub step_is_up_to_date {
 
     my $step_last_run_time = $step->last_run_time();
 
+    my $class = blessed $step;
     if (   defined $previous_steps_last_run_time
         && defined $step_last_run_time
         && $step_last_run_time >= $previous_steps_last_run_time ) {
 
-        my $class = blessed $step;
         $self->logger()
             ->info( "Last run time for $class is $step_last_run_time."
                 . " Previous steps last run time is $previous_steps_last_run_time."
@@ -124,6 +124,31 @@ sub step_is_up_to_date {
         return 1;
     }
 
+    if (   defined $previous_steps_last_run_time
+        && defined $step_last_run_time ) {
+        $self->logger()
+            ->debug( "Last run time for $class is $step_last_run_time."
+                . " Previous steps last run time is $previous_steps_last_run_time."
+                . ' Running this step.' );
+    }
+    elsif ( defined $previous_steps_last_run_time
+        && !defined $step_last_run_time ) {
+        $self->logger()
+            ->debug("No last run time for $class. Running this step.");
+    }
+    elsif ( !defined $previous_steps_last_run_time
+        && defined $step_last_run_time ) {
+        $self->logger()
+            ->debug(
+            'No last run time for the previous steps. Running this step.');
+    }
+    else {
+        $self->logger()
+            ->debug(
+            "No last run time for $class or the previous steps. Running this step."
+            );
+    }
+
     return 0;
 }
 
@@ -164,7 +189,7 @@ Stepford::Runner::State - Contains data for a single run
 
 =head1 VERSION
 
-version 0.003001
+version 0.003002
 
 =head1 DESCRIPTION
 
@@ -179,7 +204,7 @@ Dave Rolsky <drolsky@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by MaxMind, Inc..
+This software is copyright (c) 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
